# Clay documentation

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Overview

Clay is a [foundational model](#) of Earth using Earth Observation data.
As the AI Deep Learning architecture, it uses an expanded [visual
transformer](#) upgraded to understant geospatial and temporal relations
on Earth data, from any instrument/spectral data. The AI self-supervised
fundational task is a [Masked Autoencoder
(MAE)](https://arxiv.org/abs/2111.06377) approach for training.

The Clay model primarily functions in two ways: first, by directly
generating semantic embeddings for tasks like similarity searches, and
second, through fine-tuning its outputs with additional data labels.
This fine-tuning supports various tasks, including classification
(e.g. flood detection and deforestation monitoring), regression
(e.g. estimating carbon stock or crop yields), and generative tasks such
as creating RGB imagery from SAR data. Moreover, users can further
enhance model performance by incorporating higher-resolution data.

This documentation uses [nbdev](#), which combines documentation, code
samples and an SDK. This means that every page is also a python notebook
anyone can use, with practical code examples for each functionality, and
use case. Moreover, you can install `pip install clay` and use the same
functions.

Clay is open source, open data and open for business.

## Where is what

- The Clay model **code** lives on
  [Github](https://github.com/Clay-foundation/model). License:
  [Apache](https://github.com/Clay-foundation/model/LICENSE).
- The Clay model **weights** live on [Huggin Face](#). License:
  [OpenRAIL-M](https://github.com/Clay-foundation/model/blob/main/LICENSE-MODEL.md).
- The Clay **documentation** lives on here. License: [CC-BY](#).
- The Clay **SDK** lives on [PyPi](#). License: [Apache](#).
- We maintain a set of **embeddings** on [Source Cooperative](#).
  License: [ODC-BY](#).

## How to use Clay

The model can be used in two main ways:

1.  Directly, use it to make inference. See [Model](Model.html)
    1.  Check and run Benchmarks on the model. See
        [Benchmarks](Benchmarks.html)
2.  Generating semantic **embeddings**. E.g. for Similarity search. See
    [Embeddings](Embeddings.html).
3.  **Fine-tunning** the model for other tasks, or for other input data.
    E.g. flood detection, crop yields, … See
    [Fine-tunning](Fine-tunning.html).
4.  **Generative** tasks: E.g. Estimate RGB imagery wihtout clouds or
    from Synthetic Aperture Radar (SAR) data. See
    [Generative](Generative.html).

–

Clay is a fiscally sponsored project of [Radiant Earth](), a USA
registered 501(c)3 non-profit.
